Web   ·   Wiki   ·   Activities   ·   Blog   ·   Lists   ·   Chat   ·   Meeting   ·   Bugs   ·   Git   ·   Translate   ·   Archive   ·   People   ·   Donate
summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorRichard Darst <rkd@zgib.net>2009-05-07 23:17:02 (GMT)
committer Richard Darst <rkd@zgib.net>2009-05-07 23:17:02 (GMT)
commit38ae31df033a1acdec54fb8a6c596baaf0b2013a (patch)
treeb78c857423ba5e16848d345dbfb65b907823867d
parent10fcdd5753b6b3f8753055eb29e8eb7f89a866af (diff)
Renaming: MeatBot->MeetBot
- Holger and I agreed that this will replace the current eggdrop-based meetbot. But plus, the module can be named better regardless of the irc nick of our bot. darcs-hash:20090507231702-82ea9-5268cfbcc36208515436d5669f45b2f494e608a0.gz
-rw-r--r--README.txt12
-rw-r--r--__init__.py2
-rw-r--r--config.py6
-rw-r--r--meeting.py16
-rw-r--r--plugin.py8
-rw-r--r--test.py4
6 files changed, 25 insertions, 23 deletions
diff --git a/README.txt b/README.txt
index dfec6a6..6525013 100644
--- a/README.txt
+++ b/README.txt
@@ -1,8 +1,10 @@
USAGE
~~~~~
-http://wiki.debian.org/MeatBot
+http://wiki.debian.org/MeetBot
-Inspired by http://wiki.debian.org/MeetBot
+Inspired by the original MeetBot, by Holger Levsen, which was itself a
+derivative of Mootbot (https://wiki.ubuntu.com/ScribesTeam/MootBot),
+by the Ubuntu Scribes team.
/usr/share/doc/supybot/GETTING_STARTED.gz (on Debian systems) provides
information on configuring supybot the first time, including taking
@@ -23,7 +25,7 @@ Requirements:
supybot.reply.whenAddressedBy.chars:
in the config file - leave it blank afterwards.)
-* Move the MeatBot directory into your plugins directory of Supybot.
+* Move the MeetBot directory into your plugins directory of Supybot.
* Make supybot join any channels you are interested in. The wizard
handles this for the first part. After that, I guess you have to
@@ -32,12 +34,12 @@ Requirements:
command the bot after it's online.
* Make sure the plugin is loaded.
- supybot.plugins: Admin Misc User MeatBot Owner Config Channel
+ supybot.plugins: Admin Misc User MeetBot Owner Config Channel
(can also control loading after the bot is started)
Supybot does a lot, but I don't know much about it. Hopefully Supybot
expert users can enlighten me as to better ways to do things.
In particular, supybot has a large configuration system, which I know
-nothing about. It may be worth hooking MeatBot into that system.
+nothing about. It may be worth hooking MeetBot into that system.
diff --git a/__init__.py b/__init__.py
index f2b5cd8..c88ba05 100644
--- a/__init__.py
+++ b/__init__.py
@@ -48,7 +48,7 @@ __author__ = supybot.Author('Richard Darst', 'MrBeige', 'rkd@zgib.net')
__contributors__ = {}
# This is a url where the most recent plugin package can be downloaded.
-__url__ = '' # 'http://supybot.com/Members/yourname/MeatBot/download'
+__url__ = '' # 'http://supybot.com/Members/yourname/MeetBot/download'
import config
import plugin
diff --git a/config.py b/config.py
index 4668d69..734294b 100644
--- a/config.py
+++ b/config.py
@@ -37,12 +37,12 @@ def configure(advanced):
# user or not. You should effect your configuration by manipulating the
# registry as appropriate.
from supybot.questions import expect, anything, something, yn
- conf.registerPlugin('MeatBot', True)
+ conf.registerPlugin('MeetBot', True)
-MeatBot = conf.registerPlugin('MeatBot')
+MeetBot = conf.registerPlugin('MeetBot')
# This is where your configuration variables (if any) should go. For example:
-# conf.registerGlobalValue(MeatBot, 'someConfigVariableName',
+# conf.registerGlobalValue(MeetBot, 'someConfigVariableName',
# registry.Boolean(False, """Help for someConfigVariableName."""))
diff --git a/test.py b/test.py
index 73c9aae..b1ef38d 100644
--- a/test.py
+++ b/test.py
@@ -30,8 +30,8 @@
from supybot.test import *
-class MeatBotTestCase(PluginTestCase):
- plugins = ('MeatBot',)
+class MeetBotTestCase(PluginTestCase):
+ plugins = ('MeetBot',)
# vim:set shiftwidth=4 tabstop=4 expandtab textwidth=79:
diff --git a/meeting.py b/meeting.py
index bfd2470..550f925 100644
--- a/meeting.py
+++ b/meeting.py
@@ -40,16 +40,16 @@ import pygments
# Throw any overrides into meetingLocalConfig.py in this directory:
#
# Where to store files on disk
-logFileDir = '/home/richard/meatbot/'
+logFileDir = '/home/richard/meetbot/'
# The links to the logfiles are given this prefix
-logUrlPrefix = 'http://rkd.zgib.net/meatbot/'
+logUrlPrefix = 'http://rkd.zgib.net/meetbot/'
# Give the pattern to save files into here. Use %(channel)s for
# channel. This will be sent through strftime for substituting it
# times, howover, for strftime codes you must use doubled percent
# signs (%%). This will be joined with the directories above.
filenamePattern = '%(channel)s/%%Y/%(channel)s.%%F-%%H.%%M'
-# Where to say to go for more information about MeatBot
-MeetBotInfoURL = 'http://wiki.debian.org/MeatBot'
+# Where to say to go for more information about MeetBot
+MeetBotInfoURL = 'http://wiki.debian.org/MeetBot'
# This is used with the #restrict command to remove permissions from files.
RestrictPerm = stat.S_IRWXO|stat.S_IRWXG # g,o perm zeroed
# RestrictPerm = stat.S_IRWXU|stat.S_IRWXO|stat.S_IRWXG # u,g,o perm zeroed.
@@ -60,7 +60,7 @@ command_RE = re.compile('#([\w]+)(?:[ \t]*(.*))?')
# This is the help printed when a meeting starts
usefulCommands = "#action #agreed #halp #info #idea #link #topic"
# The channels which won't have date/time appended to the filename.
-specialChannels = ("#meatbot-test", "#meatbot-test2")
+specialChannels = ("#meetbot-test", "#meetbot-test2")
specialChannelFilenamePattern = '%(channel)s/%(channel)s'
# load custom local configurations
@@ -86,7 +86,7 @@ class MeetingCommands(object):
"""Begin a meeting."""
self.reply("Meeting started %s UTC. The chair is %s."%\
(time.asctime(time_), self.owner))
- self.reply(("Information about MeatBot at %s , Useful Commands: %s.")%\
+ self.reply(("Information about MeetBot at %s , Useful Commands: %s.")%\
(MeetBotInfoURL, usefulCommands))
self.starttime = time_
def do_endmeeting(self, nick, time_, **kwargs):
@@ -94,7 +94,7 @@ class MeetingCommands(object):
if not self.isChair(nick): return
self.endtime = time_
self.save()
- self.reply("Meeting ended %s UTC. Information about MeatBot at %s ."%\
+ self.reply("Meeting ended %s UTC. Information about MeetBot at %s ."%\
(time.asctime(time_),MeetBotInfoURL))
self.reply("Minutes: "+self.minutesFilename(url=True))
self.reply("Log: "+self.logFilename(url=True))
@@ -374,7 +374,7 @@ class Meeting(MeetingCommands, object):
for nick in nicks:
print >> f, ' <li>%s (%s)</li>'%(nick[0], nick[1])
print >> f, "</ol>\n\n<br>"
- print >> f, """Generated by <a href="%s">MeatBot</a>."""%MeetBotInfoURL
+ print >> f, """Generated by <a href="%s">MeetBot</a>."""%MeetBotInfoURL
print >> f, "</body></html>"
def writeRawLog(self):
"""Write raw text logs."""
diff --git a/plugin.py b/plugin.py
index 4563cac..b67a5ab 100644
--- a/plugin.py
+++ b/plugin.py
@@ -39,12 +39,12 @@ import time
import meeting
meeting = reload(meeting)
-class MeatBot(callbacks.Plugin):
- """Add the help for "@plugin help MeatBot" here
+class MeetBot(callbacks.Plugin):
+ """Add the help for "@plugin help MeetBot" here
This should describe *how* to use this plugin."""
def __init__(self, irc):
- self.__parent = super(MeatBot, self)
+ self.__parent = super(MeetBot, self)
self.__parent.__init__(irc)
self.Meetings = { }
@@ -117,7 +117,7 @@ class MeatBot(callbacks.Plugin):
savemeetings = wrap(savemeetings, ['owner'])
-Class = MeatBot
+Class = MeetBot
# vim:set shiftwidth=4 tabstop=4 expandtab textwidth=79: